==> open-xchange-mobile-api-facade_1.0.3.orig.tar.bz2: open-xchange-mobile-api-facade-1.0.3/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/utils/ListUtil.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.utils;

import java.util.ArrayList;
import java.util.List;

import lombok.experimental.UtilityClass;

@UtilityClass
public class ListUtil {

    public boolean isEmpty(List<?> list) {
        return list == null || list.isEmpty();
    }

    public <T> List<T> remove(List<T> source, List<T> toRemove) {
        List<T> destination = new ArrayList<>(source);
        destination.removeAll(toRemove);
        return destination;
    }

    public <T, RT> List<RT> map(List<T> values, MapFunction<T, RT> mapFunction) {
        if (values == null) {
            return null;
        }
        List<RT> convertedList = new ArrayList<>(values.size());
        for (T value : values) {
            convertedList.add(mapFunction.map(value));
        }
        return convertedList;
    }

}

==> open-xchange-mobile-api-facade_1.4.14.orig.tar.bz2: open-xchange-mobile-api-facade-1.4.14/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/utils/ListUtil.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.utils;

import java.util.ArrayList;
import java.util.List;

import lombok.experimental.UtilityClass;

@UtilityClass
public class ListUtil {

    public boolean isEmpty(List<?> list) {
        return list == null || list.isEmpty();
    }

    public <T> List<T> remove(List<T> source, List<T> toRemove) {
        List<T> destination = new ArrayList<>(source);
        destination.removeAll(toRemove);
        return destination;
    }

    public <T, RT> List<RT> map(List<T> values, MapFunction<T, RT> mapFunction) {
        if (values == null) {
            return null;
        }
        List<RT> convertedList = new ArrayList<>(values.size());
        for (T value : values) {
            convertedList.add(mapFunction.map(value));
        }
        return convertedList;
    }

    public <T> List<T> filter(List<T> values, FilterFunction<T> filterFunction) {
        if (values == null) {
            return null;
        }
        List<T> filteredList = new ArrayList<>(values.size());
        for (T value : values) {
            if (filterFunction.filter(value)) {
                filteredList.add(value);
            }
        }
        return filteredList;
    }

}
